==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PropertyEditorDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDataSourceDescription } from "./PropertyEditorDataSourceDescription";
/**
 * @hidden
 */
var PropertyEditorDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorDataSourceDescriptionMetadata, _super);
    function PropertyEditorDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDataSourceDescriptionMetadata.b = function (a) {
        if (PropertyEditorDataSourceDescriptionMetadata.a == null) {
            PropertyEditorDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDataSourceDescriptionMetadata.c(PropertyEditorDataSourceDescriptionMetadata.a);
        }
        if (a.g(PropertyEditorDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.s(PropertyEditorDataSourceDescriptionMetadata.a);
    };
    PropertyEditorDataSourceDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("ContextRef", "(w:Context,wf:Context)DataRef::object");
    };
    PropertyEditorDataSourceDescriptionMetadata.d = function (a) {
        PropertyEditorDataSourceDescriptionMetadata.b(a);
        a.u("PropertyEditorDataSource", function () { return new PropertyEditorDataSourceDescription(); });
        a.t("PropertyEditorDataSource", PropertyEditorDataSourceDescriptionMetadata.a);
    };
    PropertyEditorDataSourceDescriptionMetadata.$t = markType(PropertyEditorDataSourceDescriptionMetadata, 'PropertyEditorDataSourceDescriptionMetadata');
    PropertyEditorDataSourceDescriptionMetadata.a = null;
    return PropertyEditorDataSourceDescriptionMetadata;
}(Base));
export { PropertyEditorDataSourceDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PropertyEditorDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDataSourceDescription } from "./PropertyEditorDataSourceDescription";
/**
 * @hidden
 */
var PropertyEditorDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorDataSourceDescriptionMetadata, _super);
    function PropertyEditorDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDataSourceDescriptionMetadata.b = function (a) {
        if (PropertyEditorDataSourceDescriptionMetadata.a == null) {
            PropertyEditorDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDataSourceDescriptionMetadata.c(PropertyEditorDataSourceDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorDataSourceDescriptionMetadata.a);
    };
    PropertyEditorDataSourceDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("ContextRef", "(w:Context,wf:Context)DataRef::object");
    };
    PropertyEditorDataSourceDescriptionMetadata.d = function (a) {
        PropertyEditorDataSourceDescriptionMetadata.b(a);
        a.aa("PropertyEditorDataSource", function () { return new PropertyEditorDataSourceDescription(); });
        a.z("PropertyEditorDataSource", PropertyEditorDataSourceDescriptionMetadata.a);
    };
    PropertyEditorDataSourceDescriptionMetadata.$t = markType(PropertyEditorDataSourceDescriptionMetadata, 'PropertyEditorDataSourceDescriptionMetadata');
    PropertyEditorDataSourceDescriptionMetadata.a = null;
    return PropertyEditorDataSourceDescriptionMetadata;
}(Base));
export { PropertyEditorDataSourceDescriptionMetadata };
